==> sapdb-all-linux-32bit-i386-7_3_0_48.tgz: env/load2repman.py <==

# load2repman.py
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


import string
import os

_frame = '''import repmanEx

installCommands = ["""
    %s
"""]

if __name__ == '__main__':
    session = repmanEx.RepmanSession ()
    session.multiple (installCommands)
'''

def getOutputName (fname):
    base = os.path.basename (fname)
    basebase = os.path.splitext (fname) [0]
    result = basebase + '.py'
    return result

def translate (fname):
    lines = open (fname, 'r').readlines ()
    commands = []
    inComment = None
    lstrip = string.lstrip
    current = ''
    for line in lines:
        stripped = lstrip (line)
        if (len (stripped) > 0) and (stripped [0] == '/'):
            if not inComment:
                if current:
                    commands.append (current)
                current = ''
                inComment = 1
        else:
            inComment = None
            current = current + line
    if current:
        commands.append (current)
    asString = string.join (commands, '""","""\n')
    outstream = open (getOutputName (fname), 'w')
    outstream.write (_frame % asString)
    outstream.close ()

def main (options, args):
    """Translates LOAD-Scripts to 'easy' repman-Script"""
    for arg in args:
        translate (arg)

def _options ():
    return [
        # (optstring, varname, typechar, default, help)
        ]

if __name__ == '__main__':
    import optlib
    optlib.optMain2 (main, _options ())

==> sapdb-all-linux-32bit-i386-7_4_3_32.tgz: env/load2repman.py <==

# load2repman.py
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


import string
import os

_frame = '''import loaderEx

installCommands = ["""
    %s
"""]

if __name__ == '__main__':
    session = loaderEx.LoaderSession ()
    session.multiple (installCommands)
'''

def getOutputName (fname):
    base = os.path.basename (fname)
    basebase = os.path.splitext (fname) [0]
    result = basebase + '.py'
    return result

def translate (fname):
    lines = open (fname, 'r').readlines ()
    commands = []
    inComment = None
    lstrip = string.lstrip
    current = ''
    for line in lines:
        stripped = lstrip (line)
        if (len (stripped) > 0) and (stripped [0] == '/'):
            if not inComment:
                if current:
                    commands.append (current)
                current = ''
                inComment = 1
        else:
            inComment = None
            current = current + line
    if current:
        commands.append (current)
    asString = string.join (commands, '""","""\n')
    outstream = open (getOutputName (fname), 'w')
    outstream.write (_frame % asString)
    outstream.close ()

def main (options, args):
    """Translates LOAD-Scripts to 'easy' LOADER-Script"""
    for arg in args:
        translate (arg)

def _options ():
    return [
        # (optstring, varname, typechar, default, help)
        ]

if __name__ == '__main__':
    import optlib
    optlib.optMain2 (main, _options ())
